@@ -1,12 +1,11 @@
-use crate::api::subscriber_client::SubscriberClient;
 use crate::api::AcknowledgeRequest;
+use crate::client::Client;
 use anyhow::Result;
 use std::collections::HashMap;
-use tonic::transport::Channel;
 
 #[derive(Clone)]
 pub struct Message {
-    pub(crate) client: SubscriberClient<Channel>,
+    pub(crate) client: Client,
     pub(crate) data: Vec<u8>,
     pub(crate) attributes: HashMap<String, String>,
     pub(crate) ack_id: String,
@@ -21,7 +20,8 @@ impl Message {
             subscription: self.subscription_name.clone(),
             ack_ids: vec![self.ack_id.clone()],
         };
-        self.client.acknowledge(req).await?;
+        let req = self.client.insert_authz_token(req).await?;
+        self.client.subscriber.acknowledge(req).await?;
         Ok(())
     }
     pub fn data(&self) -> &[u8] {
