@@ -18,7 +18,6 @@ impl Topic {
     }
     pub async fn create_subscription(
         &mut self,
-        topic_name: &str,
         subscription_name: &str,
         filter: &str,
     ) -> Result<()> {
@@ -38,19 +37,24 @@ impl Topic {
             push_config: None,
             retain_acked_messages: false,
             retry_policy: None,
-            topic: format!("projects/{}/topics/{}", &self.client.project_id, topic_name),
+            topic: format!("projects/{}/topics/{}", &self.client.project_id, &self.name),
         };
-        self.client.subscriber.create_subscription(subs).await?;
+        let req = self.client.insert_authz_token(subs).await?;
+        self.client.subscriber.create_subscription(req).await?;
         Ok(())
     }
     pub async fn delete_subscription(&mut self, subscription_name: &str) -> Result<()> {
-        let req = api::DeleteSubscriptionRequest {
+        let delete_sub_req = api::DeleteSubscriptionRequest {
             subscription: format!(
                 "projects/{}/subscriptions/{}",
                 &self.client.project_id, subscription_name
             ),
         };
-        self.client.subscriber.delete_subscription(req).await?;
+        let authorized_req = self.client.insert_authz_token(delete_sub_req).await?;
+        self.client
+            .subscriber
+            .delete_subscription(authorized_req)
+            .await?;
         Ok(())
     }
 }
